#!/bin/bash
#
# GUI Screenshot Tool for Wayland Using Zenity, Grim, Slurp, and Rofi
# Last Modification: Wed Mar 5 2025
#

TMP_DIR=/tmp
DEFAULT_FILENAME=screenshot.png

CHOICES=(
	"1. a part of the screen"
	"2. a part of the screen and put the output into the clipboard"
	"3. whole screen"
	"4. edit"
)
CHOICE="$(rofi -dmenu -i -p "Enter option or select from the list" \
	-mesg "Select a Screenshot Option" \
	-a 0 -no-custom -location 0 \
	-yoffset 30 -xoffset 30 \
	-theme-str 'listview {columns: 1; lines: 4;} window {width: 45%;}' \
	-window-title "screenshot.sh" \
	<<< "$(printf "%s\n" "${CHOICES[@]}")")"

# echo $CHOICE

case $CHOICE in
	"1. a part of the screen")
		slurp | grim -g - "$TMP_DIR/$DEFAULT_FILENAME"
		;;
	"2. a part of the screen and put the output into the clipboard")
		slurp | grim -g - - | wl-copy
		exit
		;;
	"3. whole screen")
		grim "$TMP_DIR/$DEFAULT_FILENAME"
		;;
	"4. edit")
		grim -g "$(slurp)" - | swappy -f -
		exit
		;;
	"")
		exit
		;;
esac

FILE=$(zenity --file-selection --title="Select a File" --filename=$DEFAULT_FILENAME --save 2> /dev/null)

# echo $FILE

case $? in
	0)
		mv "$TMP_DIR/$DEFAULT_FILENAME" $FILE
		;;
	1)
		rm "$TMP_DIR/$DEFAULT_FILENAME"
		;;
	-1)
		echo "An unexpected error has occurred."
		;;
esac

exit
